pub struct ODAttributeMap { /* private fields */ }ODAttributeMap only.Expand description
Implementations
Sourceimpl ODAttributeMap
impl ODAttributeMap
pub unsafe fn customQueryFunction(&self) -> Retained<NSString>
Sourcepub unsafe fn setCustomQueryFunction(
&self,
custom_query_function: Option<&NSString>,
)
pub unsafe fn setCustomQueryFunction( &self, custom_query_function: Option<&NSString>, )
Setter for customQueryFunction.
This is copied when set.
pub unsafe fn customTranslationFunction(&self) -> Retained<NSString>
Sourcepub unsafe fn setCustomTranslationFunction(
&self,
custom_translation_function: Option<&NSString>,
)
pub unsafe fn setCustomTranslationFunction( &self, custom_translation_function: Option<&NSString>, )
Setter for customTranslationFunction.
This is copied when set.
pub unsafe fn customAttributes(&self) -> Retained<NSArray>
Sourcepub unsafe fn setCustomAttributes(&self, custom_attributes: Option<&NSArray>)
pub unsafe fn setCustomAttributes(&self, custom_attributes: Option<&NSArray>)
Setter for customAttributes.
This is copied when set.
Safety
custom_attributes generic should be of the correct type.
pub unsafe fn value(&self) -> Retained<NSString>
Sourcepub unsafe fn attributeMapWithValue(
value: Option<&NSString>,
) -> Option<Retained<Self>>
pub unsafe fn attributeMapWithValue( value: Option<&NSString>, ) -> Option<Retained<Self>>
Returns an initialized and autoreleased ODAttributeMap object with the given value mapped.
Returns an initialized and autoreleased ODAttributeMap object with the given value mapped.
Safety
value might not allow None.
Sourcepub unsafe fn attributeMapWithStaticValue(
static_value: Option<&NSString>,
) -> Option<Retained<Self>>
pub unsafe fn attributeMapWithStaticValue( static_value: Option<&NSString>, ) -> Option<Retained<Self>>
Returns an initialized and autoreleased ODAttributeMap object with the given static value.
Returns an initialized and autoreleased ODAttributeMap object with the given static value.
Safety
static_value might not allow None.
Sourcepub unsafe fn setStaticValue(&self, static_value: Option<&NSString>)
pub unsafe fn setStaticValue(&self, static_value: Option<&NSString>)
Sets a static value that will always be returned for this mapping.
Sets a static value that will always be returned for this mapping, i.e., “20”.
Safety
static_value might not allow None.
Sourcepub unsafe fn setVariableSubstitution(
&self,
variable_substitution: Option<&NSString>,
)
pub unsafe fn setVariableSubstitution( &self, variable_substitution: Option<&NSString>, )
Sets a variable substitution-based value.
Value should be using the syntax ‘$native$’ for all substited values. For example, to form a home directory using the “cn” of an LDAP record, substitution could be done with “/home/$cn$”.
Safety
variable_substitution might not allow None.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for ODAttributeMap
impl AsRef<AnyObject> for ODAttributeMap
Sourceimpl AsRef<NSObject> for ODAttributeMap
impl AsRef<NSObject> for ODAttributeMap
Sourceimpl AsRef<ODAttributeMap> for ODAttributeMap
impl AsRef<ODAttributeMap> for ODAttributeMap
Sourceimpl Borrow<AnyObject> for ODAttributeMap
impl Borrow<AnyObject> for ODAttributeMap
Sourceimpl Borrow<NSObject> for ODAttributeMap
impl Borrow<NSObject> for ODAttributeMap
Sourceimpl ClassType for ODAttributeMap
impl ClassType for ODAttributeMap
Sourceconst NAME: &'static str = "ODAttributeMap"
const NAME: &'static str = "ODAttributeMap"
Sourcetype ThreadKind = <<ODAttributeMap as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<ODAttributeMap as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for ODAttributeMap
impl Debug for ODAttributeMap
Sourceimpl Deref for ODAttributeMap
impl Deref for ODAttributeMap
Sourceimpl Hash for ODAttributeMap
impl Hash for ODAttributeMap
Sourceimpl Message for ODAttributeMap
impl Message for ODAttributeMap
Sourceimpl NSObjectProtocol for ODAttributeMap
impl NSObjectProtocol for ODAttributeMap
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref