ODFrameworkErrors

Struct ODFrameworkErrors 

#[repr(transparent)]
pub struct ODFrameworkErrors(pub c_uint);
Available on crate feature CFOpenDirectoryConstants only.
Errors specific to the framework and to underlying calls

Errors specific to the framework and to underlying calls

See also Apple’s documentation

Tuple Fields

0: c_uint

Implementations

Source

impl ODFrameworkErrors

pub const ErrorSuccess: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionLocalOnlyDaemonInUse: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionNormalDaemonInUse: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionDaemonNotRunning: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionDaemonRefused: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionProxyCommunicationError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionProxyVersionMismatch: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionProxyIPUnreachable: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorSessionProxyUnknownHost: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorNodeUnknownName: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorNodeUnknownType: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorNodeDisabled: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorNodeConnectionFailed: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorNodeUnknownHost: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorQuerySynchronize: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorQueryInvalidMatchType: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorQueryUnsupportedMatchType: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorQueryTimeout: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordReadOnlyNode: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordPermissionError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordParameterError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordInvalidType: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordAlreadyExists: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordTypeDisabled: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordNoLongerExists: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordAttributeUnknownType: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordAttributeNotFound: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordAttributeValueSchemaError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorRecordAttributeValueNotFound: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsInvalid: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsMethodNotSupported: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsNotAuthorized: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsParameterError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsOperationFailed: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsServerUnreachable: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsServerNotFound: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsServerError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsServerTimeout: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsContactPrimary: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsContactMaster: Self

👎Deprecated
Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsServerCommunicationError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsAccountNotFound: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsAccountDisabled: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsAccountExpired: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsAccountInactive: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsAccountTemporarilyLocked: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsAccountLocked: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordExpired: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordChangeRequired: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordQualityFailed: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordTooShort: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordTooLong: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordNeedsLetter: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordNeedsDigit: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordChangeTooSoon: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsPasswordUnrecoverable: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsInvalidLogonHours: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorCredentialsInvalidComputer: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorPolicyUnsupported: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorPolicyOutOfRange: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorPluginOperationNotSupported: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorPluginError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorDaemonError: Self

Available on crate feature CFOpenDirectory only.
pub const ErrorPluginOperationTimeout: Self

Available on crate feature CFOpenDirectory only.