pub struct ODMappings { /* private fields */ }ODMappings only.Expand description
Implementations
Sourceimpl ODMappings
impl ODMappings
pub unsafe fn comment(&self) -> Retained<NSString>
Sourcepub unsafe fn setComment(&self, comment: Option<&NSString>)
pub unsafe fn setComment(&self, comment: Option<&NSString>)
pub unsafe fn templateName(&self) -> Retained<NSString>
Sourcepub unsafe fn setTemplateName(&self, template_name: Option<&NSString>)
pub unsafe fn setTemplateName(&self, template_name: Option<&NSString>)
Setter for templateName.
This is copied when set.
pub unsafe fn identifier(&self) -> Retained<NSString>
Sourcepub unsafe fn setIdentifier(&self, identifier: Option<&NSString>)
pub unsafe fn setIdentifier(&self, identifier: Option<&NSString>)
Setter for identifier.
This is copied when set.
pub unsafe fn recordTypes(&self) -> Retained<NSArray>
pub unsafe fn function(&self) -> Retained<NSString>
Sourcepub unsafe fn setFunction(&self, function: Option<&NSString>)
pub unsafe fn setFunction(&self, function: Option<&NSString>)
pub unsafe fn functionAttributes(&self) -> Retained<NSArray>
Sourcepub unsafe fn setFunctionAttributes(
&self,
function_attributes: Option<&NSArray>,
)
pub unsafe fn setFunctionAttributes( &self, function_attributes: Option<&NSArray>, )
Setter for functionAttributes.
This is copied when set.
Safety
function_attributes generic should be of the correct type.
Sourcepub unsafe fn mappings() -> Option<Retained<Self>>
pub unsafe fn mappings() -> Option<Retained<Self>>
Returns an initialized and autoreleased ODMappings object.
Returns an initialized and autoreleased ODMappings object.
Sourcepub unsafe fn recordMapForStandardRecordType(
&self,
std_type: Option<&NSString>,
) -> Option<Retained<ODRecordMap>>
Available on crate feature ODRecordMap only.
pub unsafe fn recordMapForStandardRecordType( &self, std_type: Option<&NSString>, ) -> Option<Retained<ODRecordMap>>
ODRecordMap only.Returns an ODRecordMap associated with the provided recordtype.
Returns an ODRecordMap associated with the provided recordtype.
Safety
std_type might not allow None.
Sourcepub unsafe fn setRecordMap_forStandardRecordType(
&self,
map: Option<&ODRecordMap>,
std_type: Option<&NSString>,
)
Available on crate feature ODRecordMap only.
pub unsafe fn setRecordMap_forStandardRecordType( &self, map: Option<&ODRecordMap>, std_type: Option<&NSString>, )
ODRecordMap only.Sets a particular ODRecordMap for a given standard record type.
Sets a particular ODRecordMap for a given standard record type.
Safety
mapmight not allowNone.std_typemight not allowNone.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for ODMappings
impl AsRef<AnyObject> for ODMappings
Sourceimpl AsRef<NSObject> for ODMappings
impl AsRef<NSObject> for ODMappings
Sourceimpl AsRef<ODMappings> for ODMappings
impl AsRef<ODMappings> for ODMappings
Sourceimpl Borrow<AnyObject> for ODMappings
impl Borrow<AnyObject> for ODMappings
Sourceimpl Borrow<NSObject> for ODMappings
impl Borrow<NSObject> for ODMappings
Sourceimpl ClassType for ODMappings
impl ClassType for ODMappings
Sourceconst NAME: &'static str = "ODMappings"
const NAME: &'static str = "ODMappings"
Sourcetype ThreadKind = <<ODMappings as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<ODMappings as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for ODMappings
impl Debug for ODMappings
Sourceimpl Deref for ODMappings
impl Deref for ODMappings
Sourceimpl Hash for ODMappings
impl Hash for ODMappings
Sourceimpl Message for ODMappings
impl Message for ODMappings
Sourceimpl NSObjectProtocol for ODMappings
impl NSObjectProtocol for ODMappings
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref