ODQueryDelegate

Trait ODQueryDelegate 

pub unsafe trait ODQueryDelegate: NSObjectProtocol {
    // Provided method
    unsafe fn query_foundResults_error(
        &self,
        in_query: Option<&ODQuery>,
        in_results: Option<&NSArray>,
        in_error: Option<&NSError>,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature ODQuery only.
The delegate method for receiving query results from the NSRunLoop-based queries

The delegate method called as results are returned from an NSRunLoop-based query. These results are only partial and delegate is called repeatedly as results are available. The incoming result must be retained or copied. The array will be released by the NSRunLoop upon return. Incoming results do not include previous results, only the most resent results are returned. inResults can be nil if an error occurs or the query is complete. If inResults and inError are nil then the query has completed.

See also Apple’s documentation

Provided Methods

unsafe fn query_foundResults_error( &self, in_query: Option<&ODQuery>, in_results: Option<&NSArray>, in_error: Option<&NSError>, )
where Self: Sized + Message,

Safety
  • in_query might not allow None.
  • in_results generic should be of the correct type.
  • in_results might not allow None.
  • in_error might not allow None.