ODQueryCallback

Type Alias ODQueryCallback 

pub type ODQueryCallback = Option<unsafe extern "C-unwind" fn(*mut ODQueryRef, *const CFArray, *mut CFError, *mut c_void)>;
Available on crate features CFODQuery and objc2-core-foundation only.
Is called as results are returned from a query. The incoming result must be retained or copied.

Is called as results are returned from an CFRunLoop-based query. These results are only partial and the callback is called repeatedly as results are available. The incoming result must be retained or copied. The array will be released by the CFRunLoop upon return. Incoming results do not include previous results, only the most recent results are returned. inResults can be NULL if an error occurs or the query is complete. If inError and inResults are NULL then the query has completed.

See also Apple’s documentation

Aliased Type

pub enum ODQueryCallback {
    None,
    Some(unsafe extern "C-unwind" fn(*mut ODQueryRef, *const CFArray, *mut CFError, *mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C-unwind" fn(*mut ODQueryRef, *const CFArray, *mut CFError, *mut c_void))

Some value of type T.