pub struct ODConfiguration { /* private fields */ }ODConfiguration only.Expand description
Implementations
Sourceimpl ODConfiguration
impl ODConfiguration
pub unsafe fn nodeName(&self) -> Retained<NSString>
Sourcepub unsafe fn setNodeName(&self, node_name: Option<&NSString>)
pub unsafe fn setNodeName(&self, node_name: Option<&NSString>)
pub unsafe fn comment(&self) -> Retained<NSString>
Sourcepub unsafe fn setComment(&self, comment: Option<&NSString>)
pub unsafe fn setComment(&self, comment: Option<&NSString>)
pub unsafe fn defaultMappings(&self) -> Option<Retained<ODMappings>>
ODMappings only.Sourcepub unsafe fn setDefaultMappings(&self, default_mappings: Option<&ODMappings>)
Available on crate feature ODMappings only.
pub unsafe fn setDefaultMappings(&self, default_mappings: Option<&ODMappings>)
ODMappings only.pub unsafe fn templateName(&self) -> Retained<NSString>
Sourcepub unsafe fn setTemplateName(&self, template_name: Option<&NSString>)
pub unsafe fn setTemplateName(&self, template_name: Option<&NSString>)
Setter for templateName.
This is copied when set.
pub unsafe fn virtualSubnodes(&self) -> Retained<NSArray>
Sourcepub unsafe fn setVirtualSubnodes(&self, virtual_subnodes: Option<&NSArray>)
pub unsafe fn setVirtualSubnodes(&self, virtual_subnodes: Option<&NSArray>)
Setter for virtualSubnodes.
This is copied when set.
Safety
virtual_subnodes generic should be of the correct type.
pub unsafe fn hideRegistration(&self) -> bool
Sourcepub unsafe fn setHideRegistration(&self, hide_registration: bool)
pub unsafe fn setHideRegistration(&self, hide_registration: bool)
Setter for hideRegistration.
pub unsafe fn preferredDestinationHostName(&self) -> Retained<NSString>
Sourcepub unsafe fn setPreferredDestinationHostName(
&self,
preferred_destination_host_name: Option<&NSString>,
)
pub unsafe fn setPreferredDestinationHostName( &self, preferred_destination_host_name: Option<&NSString>, )
Setter for preferredDestinationHostName.
This is copied when set.
pub unsafe fn preferredDestinationHostPort(&self) -> u16
Sourcepub unsafe fn setPreferredDestinationHostPort(
&self,
preferred_destination_host_port: u16,
)
pub unsafe fn setPreferredDestinationHostPort( &self, preferred_destination_host_port: u16, )
Setter for preferredDestinationHostPort.
pub unsafe fn trustAccount(&self) -> Retained<NSString>
pub unsafe fn trustMetaAccount(&self) -> Retained<NSString>
pub unsafe fn trustKerberosPrincipal(&self) -> Retained<NSString>
pub unsafe fn trustType(&self) -> Retained<NSString>
pub unsafe fn trustUsesMutualAuthentication(&self) -> bool
pub unsafe fn trustUsesKerberosKeytab(&self) -> bool
pub unsafe fn trustUsesSystemKeychain(&self) -> bool
pub unsafe fn packetSigning(&self) -> NSInteger
Sourcepub unsafe fn setPacketSigning(&self, packet_signing: NSInteger)
pub unsafe fn setPacketSigning(&self, packet_signing: NSInteger)
Setter for packetSigning.
pub unsafe fn packetEncryption(&self) -> NSInteger
Sourcepub unsafe fn setPacketEncryption(&self, packet_encryption: NSInteger)
pub unsafe fn setPacketEncryption(&self, packet_encryption: NSInteger)
Setter for packetEncryption.
pub unsafe fn manInTheMiddleProtection(&self) -> bool
Sourcepub unsafe fn setManInTheMiddleProtection(
&self,
man_in_the_middle_protection: bool,
)
pub unsafe fn setManInTheMiddleProtection( &self, man_in_the_middle_protection: bool, )
Setter for manInTheMiddleProtection.
pub unsafe fn queryTimeoutInSeconds(&self) -> NSInteger
Sourcepub unsafe fn setQueryTimeoutInSeconds(
&self,
query_timeout_in_seconds: NSInteger,
)
pub unsafe fn setQueryTimeoutInSeconds( &self, query_timeout_in_seconds: NSInteger, )
Setter for queryTimeoutInSeconds.
pub unsafe fn connectionSetupTimeoutInSeconds(&self) -> NSInteger
Sourcepub unsafe fn setConnectionSetupTimeoutInSeconds(
&self,
connection_setup_timeout_in_seconds: NSInteger,
)
pub unsafe fn setConnectionSetupTimeoutInSeconds( &self, connection_setup_timeout_in_seconds: NSInteger, )
Setter for connectionSetupTimeoutInSeconds.
pub unsafe fn connectionIdleTimeoutInSeconds(&self) -> NSInteger
Sourcepub unsafe fn setConnectionIdleTimeoutInSeconds(
&self,
connection_idle_timeout_in_seconds: NSInteger,
)
pub unsafe fn setConnectionIdleTimeoutInSeconds( &self, connection_idle_timeout_in_seconds: NSInteger, )
Setter for connectionIdleTimeoutInSeconds.
pub unsafe fn defaultModuleEntries(&self) -> Retained<NSArray>
Sourcepub unsafe fn setDefaultModuleEntries(
&self,
default_module_entries: Option<&NSArray>,
)
pub unsafe fn setDefaultModuleEntries( &self, default_module_entries: Option<&NSArray>, )
Setter for defaultModuleEntries.
This is copied when set.
Safety
default_module_entries generic should be of the correct type.
pub unsafe fn authenticationModuleEntries(&self) -> Retained<NSArray>
Sourcepub unsafe fn setAuthenticationModuleEntries(
&self,
authentication_module_entries: Option<&NSArray>,
)
pub unsafe fn setAuthenticationModuleEntries( &self, authentication_module_entries: Option<&NSArray>, )
Setter for authenticationModuleEntries.
This is copied when set.
Safety
authentication_module_entries generic should be of the correct type.
pub unsafe fn discoveryModuleEntries(&self) -> Retained<NSArray>
Sourcepub unsafe fn setDiscoveryModuleEntries(
&self,
discovery_module_entries: Option<&NSArray>,
)
pub unsafe fn setDiscoveryModuleEntries( &self, discovery_module_entries: Option<&NSArray>, )
Setter for discoveryModuleEntries.
This is copied when set.
Safety
discovery_module_entries generic should be of the correct type.
pub unsafe fn generalModuleEntries(&self) -> Retained<NSArray>
Sourcepub unsafe fn setGeneralModuleEntries(
&self,
general_module_entries: Option<&NSArray>,
)
pub unsafe fn setGeneralModuleEntries( &self, general_module_entries: Option<&NSArray>, )
Setter for generalModuleEntries.
This is copied when set.
Safety
general_module_entries generic should be of the correct type.
Sourcepub unsafe fn configuration() -> Option<Retained<Self>>
pub unsafe fn configuration() -> Option<Retained<Self>>
Returns an initialized and autoreleased ODConfiguration object.
Returns an initialized and autoreleased ODConfiguration object.
Sourcepub unsafe fn suggestedTrustAccount(
hostname: Option<&NSString>,
) -> Option<Retained<NSString>>
pub unsafe fn suggestedTrustAccount( hostname: Option<&NSString>, ) -> Option<Retained<NSString>>
Returns a suggested name to use for the trust account.
Returns a suggested name to use for a trust account. This name will be derived from the hostname (if provided), otherwise it will be derived from the local hostname removing special characters that may not be allowed by many systems.
Safety
hostname might not allow None.
Sourcepub unsafe fn suggestedTrustPassword(
length: usize,
) -> Option<Retained<NSString>>
pub unsafe fn suggestedTrustPassword( length: usize, ) -> Option<Retained<NSString>>
Returns a suggested password to be used for trust account with the requested length.
Returns a suggested password to be used for trust account with the requested length.
Sourcepub unsafe fn saveUsingAuthorization_error(
&self,
authorization: Option<&SFAuthorization>,
error: Option<&mut Option<Retained<NSError>>>,
) -> bool
Available on crate feature objc2-security-foundation only.
pub unsafe fn saveUsingAuthorization_error( &self, authorization: Option<&SFAuthorization>, error: Option<&mut Option<Retained<NSError>>>, ) -> bool
objc2-security-foundation only.Saves the configuration using the provided authorization.
Saves the configuration using the provided authorization.
Safety
authorizationmight not allowNone.errormight not allowNone.
Sourcepub unsafe fn addTrustType_trustAccount_trustPassword_username_password_joinExisting_error(
&self,
trust_type: Option<&NSString>,
account: Option<&NSString>,
account_password: Option<&NSString>,
username: Option<&NSString>,
password: Option<&NSString>,
join: bool,
error: Option<&mut Option<Retained<NSError>>>,
) -> bool
pub unsafe fn addTrustType_trustAccount_trustPassword_username_password_joinExisting_error( &self, trust_type: Option<&NSString>, account: Option<&NSString>, account_password: Option<&NSString>, username: Option<&NSString>, password: Option<&NSString>, join: bool, error: Option<&mut Option<Retained<NSError>>>, ) -> bool
Adds a trust account with the provided name and password using the credentials provided by the user.
Adds a trust account with the provided name and password using the credentials provided by the user. User can request that the trust be forcibly created (replacing existing trust if found in directory). A trust should be established only after enough configuration is available and the configuration been saved. If the trust is required, then the configuration can be deleted if necessary upon failure.
Safety
trust_typemight not allowNone.accountmight not allowNone.account_passwordmight not allowNone.usernamemight not allowNone.passwordmight not allowNone.errormight not allowNone.
Sourcepub unsafe fn removeTrustUsingUsername_password_deleteTrustAccount_error(
&self,
username: Option<&NSString>,
password: Option<&NSString>,
delete_account: bool,
error: Option<&mut Option<Retained<NSError>>>,
) -> bool
pub unsafe fn removeTrustUsingUsername_password_deleteTrustAccount_error( &self, username: Option<&NSString>, password: Option<&NSString>, delete_account: bool, error: Option<&mut Option<Retained<NSError>>>, ) -> bool
Removes trust using the provided username and password.
Removes trust using the provided username and password. The trust account will be removed from the directory only if requested.
Safety
usernamemight not allowNone.passwordmight not allowNone.errormight not allowNone.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for ODConfiguration
impl AsRef<AnyObject> for ODConfiguration
Sourceimpl AsRef<NSObject> for ODConfiguration
impl AsRef<NSObject> for ODConfiguration
Sourceimpl AsRef<ODConfiguration> for ODConfiguration
impl AsRef<ODConfiguration> for ODConfiguration
Sourceimpl Borrow<AnyObject> for ODConfiguration
impl Borrow<AnyObject> for ODConfiguration
Sourceimpl Borrow<NSObject> for ODConfiguration
impl Borrow<NSObject> for ODConfiguration
Sourceimpl ClassType for ODConfiguration
impl ClassType for ODConfiguration
Sourceconst NAME: &'static str = "ODConfiguration"
const NAME: &'static str = "ODConfiguration"
Sourcetype ThreadKind = <<ODConfiguration as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<ODConfiguration as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for ODConfiguration
impl Debug for ODConfiguration
Sourceimpl Deref for ODConfiguration
impl Deref for ODConfiguration
Sourceimpl Hash for ODConfiguration
impl Hash for ODConfiguration
Sourceimpl Message for ODConfiguration
impl Message for ODConfiguration
Sourceimpl NSObjectProtocol for ODConfiguration
impl NSObjectProtocol for ODConfiguration
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref